==> openmpi_1.4.3.orig.tar.gz: openmpi-1.4.3/ompi/runtime/ompi_cr.h <==
/*
 * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2005 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * $COPYRIGHT$
 * 
 * Additional copyrights may follow
 * 
 * $HEADER$
 */

/** 
 * @file 
 *
 * Checkpoint/Restart Functionality for the OMPI layer
 */

#ifndef OMPI_CR_H
#define OMPI_CR_H

#if defined(c_plusplus) || defined(__cplusplus)
extern "C" {
#endif

    /*
     * Initialization called in ompi_init()
     */
    OMPI_DECLSPEC int ompi_cr_init(void);

    /*
     * Finalization called in ompi_finalize()
     */
    OMPI_DECLSPEC int ompi_cr_finalize(void);

    /*
     * Interlayer Coodination Callback
     */
    OMPI_DECLSPEC int ompi_cr_coord(int state);

    /*
     * A general output handle to use for FT related messages
     */
    OMPI_DECLSPEC extern int ompi_cr_output;

    /*
     * If one of the BTLs that shutdown require a full, clean rebuild of the
     * point-to-point stack on 'continue' as well as 'restart'.
     */
    OPAL_DECLSPEC extern bool ompi_cr_continue_like_restart;

#if defined(c_plusplus) || defined(__cplusplus)
}
#endif

#endif /* OMPI_CR_H */

==> openmpi1.5_1.5.4.orig.tar.gz: openmpi-1.5.4/ompi/runtime/ompi_cr.h <==
/*
 * Copyright (c) 2004-2007 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2005 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart, 
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * $COPYRIGHT$
 * 
 * Additional copyrights may follow
 * 
 * $HEADER$
 */

/** 
 * @file 
 *
 * Checkpoint/Restart Functionality for the OMPI layer
 */

#ifndef OMPI_CR_H
#define OMPI_CR_H

#include "ompi_config.h"

BEGIN_C_DECLS

    /*
     * Initialization called in ompi_init()
     */
    OMPI_DECLSPEC int ompi_cr_init(void);

    /*
     * Finalization called in ompi_finalize()
     */
    OMPI_DECLSPEC int ompi_cr_finalize(void);

    /*
     * Interlayer Coodination Callback
     */
    OMPI_DECLSPEC int ompi_cr_coord(int state);

    /*
     * A general output handle to use for FT related messages
     */
    OMPI_DECLSPEC extern int ompi_cr_output;

    /*
     * If one of the BTLs that shutdown require a full, clean rebuild of the
     * point-to-point stack on 'continue' as well as 'restart'.
     */
    OPAL_DECLSPEC extern bool ompi_cr_continue_like_restart;

END_C_DECLS

#endif /* OMPI_CR_H */
